<div class="stream-head-container">
	<div class="stream-head-text-container text-danger">
		{{complexText message}}
	</div>
</div>
<div class="stream-date-container">
    <span class="text-muted small">{{{createdAt}}}</span>
</div>
