
<select class="form-control search-type input-sm">
    {{options searchTypeList searchType field='searchRanges'}}
</select>
<div class="input-container">
    <input class="main-element" type="text" autocomplete="espo-off">
</div>
