<div>
    <div class="pull-right">
        <a role="button" tabindex="0" data-action="editConditions">{{translate 'Edit'}}</a>
    </div>
    <div class="top-group-string-container">
        {{{conditionGroup}}}
    </div>
</div>
