<select data-name="{{name}}" class="form-control main-element">
    {{options
        params.options value
        scope=scope
        field=name
        translatedOptions=translatedOptions
        includeMissingOption=true
        styleMap=params.style
    }}
</select>
