<span title="{{value}}">{{value}}</span>
<span class="list-icon-container"{{#unless isReplied}} style="display: none;"{{/unless}}>
    <span
        class="fas icon-is-replied fa-sm text-muted icon-flip-horizontal"
        title="{{translate 'isReplied' category='fields' scope='Email'}}"
    ></span>
</span>
