<div class="page-header"><h3><a href="#Admin">{{translate 'Administration'}}</a>
<span class="breadcrumb-separator"><span class="chevron-right"></span></span>
{{translate 'Formula Sandbox' scope='Admin'}}</h3></div>


<div class="record">{{{record}}}</div>
