<div class="panel panel-default">
    <div class="panel-heading panel-heading-no-title">
    <div class="link-group">
        <a role="button" tabindex="0" class="close-link" data-action="closePanel"><span class="fas fa-times"></span></a>
    </div>
    {{translate 'Global Search'}}
    </div>
    <div class="panel-body">
        <div class="list-container">
            <span class="text-soft fas fa-spinner fa-spin"></span>
        </div>
    </div>
</div>
