<div class="search-container margin-bottom">{{{search}}}</div>

{{#unless categoriesDisabled}}
<div class="row row-list-container">
    <div class="categories-container col-md-3 col-sm-4">{{{categories}}}</div>
    <div class="list-container col-md-9 col-sm-8">{{{list}}}</div>
</div>
{{else}}
<div class="list-container">{{{list}}}</div>
{{/unless}}
