<textarea
	class="main-element form-control hidden auto-height"
	data-name="{{name}}"
	{{#if params.maxLength}} maxlength="{{params.maxLength}}"{{/if}}
	rows="{{rows}}"
	style="resize: none;"
></textarea>
<div class="summernote hidden"></div>
