<div class="stream-head-container">
    <div class="pull-left">
        {{{avatar}}}
    </div>
	<div class="stream-head-text-container text-muted message">
		{{{message}}}
	</div>
</div>
<div class="stream-date-container">
    <span class="text-muted small">{{{createdAt}}}</span>
</div>
