<div class="row">
    <div data-name="{{field}}" class="cell col-sm-12">
        <label class="control-label" data-name="{{field}}">
            {{translate field category='fields' scope='EntityManager'}}
        </label>
        <div class="field" data-name="{{field}}">
            {{{var fieldKey this}}}
        </div>
    </div>
</div>
