<div class="panel panel-default no-side-margin">
    <div class="panel-body">
        <div class="cell form-group">
            <label class="control-label">{{labels.textToDisplay}}</label>
            <div class="field">
                <input class="form-control note-form-control note-input" type="text" data-name="text">
            </div>
        </div>
        <div class="cell form-group">
            <label class="control-label">{{labels.url}}</label>
            <div class="field">
                <input class="form-control note-form-control note-input" type="text" data-name="url">
            </div>
        </div>
        <div class="cell form-group">
            <label class="control-label">{{labels.openInNewWindow}}</label>
            <div class="field">
                <input class="form-checkbox" type="checkbox" data-name="openInNewWindow" checked>
            </div>
        </div>
    </div>
</div>
