<div class="panel no-side-margin">
    <div class="panel-body">

        <p>{{translate 'verifyTotpCode' category='messages' scope='User'}}</p>

        <div style="margin-top: 20px; background: #FFF; padding: 20px;">
            <div class="qrcode"></div>
        </div>
    </div>
</div>

<div class="record no-side-margin">{{{record}}}</div>
