<div class="page-header">
    <h3>EspoCRM – Open Source CRM application</h3>
</div>

<div class="row">
    <div class="col-md-8">
        <div class="panel panel-default">
            <div class="panel-body">
                <h5>Version {{version}}</h5>
                <p>
                    Copyright &copy; 2014-2023 EspoCRM: Yurii Kuznietsov, Taras Machyshyn, Oleksii Avramenko.
                </p>
                <p>
                    Website: <a href="https://www.espocrm.com" target="_BLANK">www.espocrm.com</a>.
                </p>
                <p>
                    EspoCRM is free software: you can redistribute it and/or modify
                    it under the terms of the GNU General Public License as published by
                    the Free Software Foundation, either version 3 of the License, or
                    (at your option) any later version.
                </p>
                <p>
                    EspoCRM is distributed in the hope that it will be useful,
                    but WITHOUT ANY WARRANTY; without even the implied warranty
                    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
                </p>
                <p>
                    You should have received a copy of the GNU General Public License
                    along with EspoCRM. If not, see http://www.gnu.org/licenses/.
                </p>

                <p>
                    The interactive user interfaces in modified source and object code versions
                    of this program must display Appropriate Legal Notices, as required under
                    Section 5 of the GNU General Public License version 3.
                </p>

                <p>
                    In accordance with Section 7(b) of the GNU General Public License version 3,
                    these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
                </p>
            </div>
        </div>
    </div>
</div>
