<div class="input-group" style="table-layout: fixed; width: 100%;">
    <span class="input-group-item" style="width: 40%;">
        <select
            data-name="variables"
            class="main-element form-control radius-left"
        >{{{options attributeList '' translatedOptions=translatedOptions}}}</select>
    </span>
    <span class="input-group-item">
        <input data-name="copy" class="form-control" readonly="true">
    </span>
</div>
