<link href="{{basePath}}client/css/cropper.css" rel="stylesheet">
<div class="row">
    <div class="col-sm-6">
        <div style="text-align: center;" class="image-container"></div>
    </div>
    <div class="col-sm-6">
        <div class="btn-group">
            <button class="btn btn-default btn-icon" data-action="zoomIn"><span class="fas fa-search-plus"></span></button>
            <button class="btn btn-default btn-icon" data-action="zoomOut"><span class="fas fa-search-minus"></span></button>
        </div>
    </div>
</div>
