<a role="button" tabindex="0" class="notifications-button" data-action="showNotifications">
    <span class="fas fa-bell icon bell"></span>
    <span class="badge number-badge hidden"></span>
</a>
<div class="notifications-panel-container"></div>
