<div class="panel panel-default no-side-margin">
<div class="panel-body">

<div class="cell form-group" data-name="name">
    <label class="control-label" data-name="name">{{translate 'Name' category='fields'}}</label>
    <div class="field" data-name="name">
        {{{name}}}
    </div>
</div>

</div>
</div>
