<h3><a href="#Admin">{{translate 'Administration'}}</a>
<span class="breadcrumb-separator"><span class="chevron-right"></span></span>
{{translate viewObject.options.label category='labels' scope='Admin'}}</h3>
