<div class="record no-side-margin">{{{record}}}</div>

<div class="well info-text">{{complexText infoText}}</div>

<div class="margin-top download-container hidden">
	<button type="button" class="btn btn-default download-button" data-action="download">{{translate 'Download'}}</button>
</div>
