<div class="container">
    <div class="panel panel-default block-center-md margin-top-2x">
        <div class="panel-body">
            <h1 class="text-5em text-soft margin-bottom-4x">403</h1>
            <p class="text-large">{{translate 'error403' category='messages'}}</p>
        </div>
    </div>
</div>
