<div class="panel panel-default no-focus-outline" tabindex="-1">
    <div class="panel-heading panel-heading-no-title">
        <div class="link-group">
            <a href="#Notification" data-action="openNotifications">{{translate 'View List'}}</a>
            <a role="button" tabindex="0" data-action="markAllNotificationsRead">{{translate 'Mark all read'}}</a>
            <a role="button" tabindex="0" class="close-link" data-action="closePanel"><span class="fas fa-times"></span></a>
        </div>
        {{translate 'Notifications'}}
    </div>
    <div class="panel-body">
        <div class="list-container">
            <span class="text-soft fas fa-spinner fa-spin"></span>
        </div>
    </div>
</div>
