<div class="panel panel-default no-side-margin">
<div class="panel-body">

<div class="row">
    <div class="cell col-md-6 form-group" data-name="currency">
        <label class="control-label" data-name="currency">{{translate 'Convert to'}}</label>
        <div class="field" data-name="currency">{{{currency}}}</div>
    </div>
</div>
<div class="row">
    <div class="cell col-md-6 form-group" data-name="baseCurrency">
        <label class="control-label" data-name="baseCurrency">{{translate 'baseCurrency' category='fields' scope='Settings'}}</label>
        <div class="field" data-name="baseCurrency">{{{baseCurrency}}}</div>
    </div>
</div>
<div class="row">
    <div class="cell col-md-6 form-group" data-name="currencyRates">
        <label class="control-label" data-name="currencyRates">{{translate 'currencyRates' category='fields' scope='Settings'}}</label>
        <div class="field" data-name="currencyRates">{{{currencyRates}}}</div>
    </div>
</div>

</div>
</div>