<div class="container content">
    <div class="block-center-md">
        <div class="panel panel-success">
            <div class="panel-body">
                <p>
                    {{defaultMessage}}
                </p>
            </div>
        </div>
    </div>
</div>
