<div class="row">
    <div class="col-sm-4 col-xs-6">
        <select class="form-control" data-name="entityType"></select>
    </div>
    <div class="col-sm-5 col-xs-6">
        <select class="form-control" data-name="field"></select>
    </div>
    <div class="col-sm-3 col-xs-6">
        <button class="btn btn-default" type="button" data-action="insert">{{translate 'Insert'}}</button>
    </div>
</div>
